@@ -1,5 +1,6 @@
 import shutil
 import os
+from pathlib import Path as Pa
 
 from chromie.utils import ChromiePathFinder, ManifestFile
 from chromie.enum import Initialize, Path
@@ -7,7 +8,8 @@ from chromie.enum import Initialize, Path
 
 def make_extension_dir(finder):
     for d in [Path.DIST_DIR, Path.SRC_DIR, Path.STORE_DIR, Path.IMAGES_DIR]:
-        os.makedirs(os.path.join(finder.root, d))
+        p = Pa(os.path.join(finder.root, d))
+        p.mkdir(parents=True)
 
     with open(finder(Path.IGNORE_FILE), "w") as f:
         f.write("")
@@ -24,7 +26,6 @@ def init(args):
     overwrite = args.overwrite
 
     finder = ChromiePathFinder(args.filepath, name)
-    print(finder.root)
 
     if not overwrite and finder.exists() == True:
         asked = 0
